"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getArrayType = exports.getRelationProperty = exports.getPrimaryColumnType = exports.getPrimaryColumnName = exports.getPropsNullable = exports.getPropsType = exports.getProps = exports.getRelation = void 0;
const json_api_nestjs_1 = require("@klerick/json-api-nestjs");
const constants_1 = require("../constants");
const getRelation = (entityMetadata) => entityMetadata.relations.map((i) => i.name);
exports.getRelation = getRelation;
const getProps = (entityMetadata) => {
    const relations = (0, exports.getRelation)(entityMetadata);
    return entityMetadata.props
        .map((i) => i.name)
        .filter((i) => !relations.includes(i));
};
exports.getProps = getProps;
const getPropsType = (entityMetadata, config = constants_1.DEFAULT_ARRAY_TYPE) => {
    const field = (0, exports.getProps)(entityMetadata);
    const result = {};
    for (const item of field) {
        const props = entityMetadata.properties[item];
        let typeProps = json_api_nestjs_1.TypeField.string;
        if (config.includes(props['type'])) {
            result[item] = json_api_nestjs_1.TypeField.array;
            continue;
        }
        switch (props.runtimeType) {
            case 'Date':
                typeProps = json_api_nestjs_1.TypeField.date;
                break;
            case 'number':
                typeProps = json_api_nestjs_1.TypeField.number;
                break;
            case 'boolean':
                typeProps = json_api_nestjs_1.TypeField.boolean;
                break;
            case 'object':
                typeProps = json_api_nestjs_1.TypeField.object;
                break;
            default:
                typeProps = json_api_nestjs_1.TypeField.string;
        }
        result[item] = typeProps;
    }
    return result;
};
exports.getPropsType = getPropsType;
const getPropsNullable = (entityMetadata) => {
    return (0, exports.getProps)(entityMetadata)
        .map((i) => {
        // @ts-ignore
        const props = entityMetadata.properties[i];
        return props.nullable ||
            props.default !== undefined ||
            props.defaultRaw !== undefined
            ? i
            : false;
    })
        .filter((i) => !!i);
};
exports.getPropsNullable = getPropsNullable;
const getPrimaryColumnName = (entityMetadata) => entityMetadata
    .getPrimaryProp()
    .name.toString();
exports.getPrimaryColumnName = getPrimaryColumnName;
const getPrimaryColumnType = (entityMetadata) => {
    return (entityMetadata.getPrimaryProp().runtimeType === 'number'
        ? json_api_nestjs_1.TypeField.number
        : json_api_nestjs_1.TypeField.string);
};
exports.getPrimaryColumnType = getPrimaryColumnType;
const getRelationProperty = (entityMetadata) => {
    return entityMetadata.relations.reduce((acum, item) => {
        // @ts-expect-error its dynamic creater
        acum[item.name] = {
            entityClass: item.entity(),
            nullable: item.kind === 'm:n' || item.kind === '1:m'
                ? false
                : !!item.nullable,
            isArray: item.kind === 'm:n' || item.kind === '1:m',
        };
        return acum;
    }, {});
};
exports.getRelationProperty = getRelationProperty;
const getArrayType = (repository, config = constants_1.DEFAULT_ARRAY_TYPE) => {
    return Object.entries((0, exports.getPropsType)(repository, config))
        .filter(([name, type]) => type === json_api_nestjs_1.TypeField.array)
        .reduce((acum, [name]) => {
        const fieldType = Reflect.get(repository.properties, name)
            .columnTypes.at(0)
            ?.replace('[]', '');
        if (!fieldType) {
            throw new Error('Metadata not found for field ' + name);
        }
        switch (fieldType) {
            case 'number':
            case 'bigint':
            case 'smallint':
            case 'smalldecimal':
            case 'decimal':
            case 'double':
            case 'tinyint':
            case 'mediumint':
            case 'int':
            case 'float':
            case 'dec':
            case 'fixed':
            case 'numeric':
            case 'real':
            case 'int2':
            case 'int4':
            case 'int8':
            case 'integer':
                acum[name] = json_api_nestjs_1.TypeField.number;
                break;
            case 'character varying':
            case 'varying character':
            case 'char varying':
            case 'nvarchar':
            case 'national varchar':
            case 'character':
            case 'native character':
            case 'varchar':
            case 'char':
            case 'nchar':
            case 'national char':
            case 'varchar2':
            case 'nvarchar2':
            case 'alphanum':
            case 'shorttext':
            case 'raw':
            case 'binary':
            case 'varbinary':
            case 'string':
                acum[name] = json_api_nestjs_1.TypeField.string;
                break;
            case 'date':
            case 'timetz':
            case 'timestamptz':
            case 'timestamp with local time zone':
            case 'smalldatetime':
                acum[name] = json_api_nestjs_1.TypeField.date;
                break;
            case 'boolean':
                acum[name] = json_api_nestjs_1.TypeField.boolean;
        }
        return acum;
    }, {});
};
exports.getArrayType = getArrayType;
//# sourceMappingURL=index.js.map